==> yaf-2.0.0.tgz: yaf-2.0.0/yaf_session.h <==
/*
  +----------------------------------------------------------------------+
  | Yet Another Framework                                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Laruence<laruence@yahoo.com.cn>                              |
  +----------------------------------------------------------------------+
   $Id: yaf_session.h 53 2011-06-01 02:57:04Z laruence $
 */

#ifndef YAF_SESSION_H
#define YAF_SESSION_H

#define YAF_SESSION_PROPERTY_NAME_STATUS	    "_started"
#define YAF_SESSION_PROPERTY_NAME_SESSION	"_session"
#define YAF_SESSION_PROPERTY_NAME_INSTANCE	"_instance"

extern zend_class_entry *yaf_session_ce;

PHPAPI void php_session_start(TSRMLS_D);
YAF_STARTUP_FUNCTION(session);
#endif
/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> yaf-2.0.1.tgz: yaf-2.0.1/yaf_session.h <==
/*
  +----------------------------------------------------------------------+
  | Yet Another Framework                                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Xinchen Hui  <laruence@php.net>                              |
  +----------------------------------------------------------------------+
   $Id: yaf_session.h 312522 2011-06-27 11:08:27Z laruence $
 */

#ifndef YAF_SESSION_H
#define YAF_SESSION_H

#define YAF_SESSION_PROPERTY_NAME_STATUS	    "_started"
#define YAF_SESSION_PROPERTY_NAME_SESSION	"_session"
#define YAF_SESSION_PROPERTY_NAME_INSTANCE	"_instance"

extern zend_class_entry *yaf_session_ce;

PHPAPI void php_session_start(TSRMLS_D);
YAF_STARTUP_FUNCTION(session);
#endif
/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
